pub trait Channel:
PeripheralType
+ SealedChannel
+ Sized {
type IRQ: InterruptType;
// Required methods
fn number(&self) -> PinNumber;
fn irq(&self) -> InterruptEnum;
}Expand description
EXTI channel trait.
Required Associated Types
Sourcetype IRQ: InterruptType
type IRQ: InterruptType
Type-level Interrupt, which may be the same for multiple channels.
Required Methods
Sourcefn irq(&self) -> InterruptEnum
fn irq(&self) -> InterruptEnum
Enum-level Interrupt, which may be the same for multiple channels.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".